Index: qtools/qfileinfo_win32.cpp
===================================================================
--- qtools/qfileinfo_win32.cpp	(revision 770)
+++ qtools/qfileinfo_win32.cpp	(working copy)
@@ -20,6 +20,8 @@
 
 #include "qglobal.h"
 
+#include <windows.h>
+
 #include "qfileinfo.h"
 #include "qfiledefs_p.h"
 #include "qdatetime.h"
@@ -246,6 +248,46 @@
     return dt;
 }
 
+#ifndef __CYGWIN32_
+inline
+bool IsReparsePoint(const QString &path)
+{
+  DWORD result = GetFileAttributesW((const wchar_t *)path.ucs2());
+  return (result != INVALID_FILE_ATTRIBUTES) && (result & FILE_ATTRIBUTE_REPARSE_POINT);
+}
+
+QString GetReparseLocation(const QString &path)
+{
+  HANDLE hFile = CreateFileW((const wchar_t *)path.ucs2(),               // file to open
+    0,                      // access metadata only
+    FILE_SHARE_READ,       // share for reading
+    NULL,                  // default security
+    OPEN_EXISTING,         // existing file only
+    FILE_FLAG_BACKUP_SEMANTICS, // allow Directories to be opened
+    NULL);                 // no attr. template
+
+  if (hFile == INVALID_HANDLE_VALUE)    // cannot open the drive
+  {
+    return "";
+  }
+
+  static const DWORD PATH_LENGTH = 32767;
+  char targetPath[PATH_LENGTH];
+
+  DWORD strLen = GetFinalPathNameByHandle(hFile, (LPSTR)&targetPath, PATH_LENGTH, 0);
+
+  CloseHandle(hFile);
+
+  if (strLen < 5 || strLen > PATH_LENGTH)
+  {
+    return "";
+  }
+
+  QString result = targetPath + 4;// strip leading \\?\ characters
+  return result;
+}
+
+#endif
 
 void QFileInfo::doStat() const
 {
@@ -267,6 +309,13 @@
 #else
     QString file = fn;
     reslashify(file);
+
+    if (IsReparsePoint(file))
+    {
+      // _stat does not work for some symlinks. need to obtain pointed-to file
+      that->fic->isSymLink = TRUE;
+      file = GetReparseLocation(file);
+    }
 #ifdef QT_LARGEFILE_SUPPORT
     if ( _wstati64( (wchar_t*) file.ucs2(), b ) == -1 ) {
 #else
